# apparmor.d - Full set of apparmor profiles
# Copyright (C) 2024 Alexandre Pujol <alexandre@pujol.io>
# SPDX-License-Identifier: GPL-2.0-only

abi <abi/4.0>,

include <tunables/global>

@{exec_path} = @{bin}/epiphany
profile epiphany /{,usr/}{,s}bin/epiphany  flags=(attach_disconnected,complain) {
  include <abstractions/base>
  include <abstractions/audio-server>
  include <abstractions/bus-system>
  include <abstractions/bus/org.freedesktop.GeoClue2>
  include <abstractions/common/bwrap>
  include <abstractions/common/gnome>
  include <abstractions/gstreamer>
  include <abstractions/nameservice-strict>
  include <abstractions/p11-kit>
  include <abstractions/ssl_certs>
  include <abstractions/user-download-strict>

  capability dac_override,

  network inet dgram,
  network inet stream,
  network inet6 dgram,
  network inet6 stream,
  network netlink raw,

  mount options=(rw rbind) /bindfile@{rand6} -> /newroot/.flatpak-info,

  @{exec_path} mr,

  @{open_path}  rpx -> child-open,

  @{bin}/bwrap           rix,
  @{bin}/xdg-dbus-proxy  rix,
  @{lib}/{,@{multiarch}/}webkit{,2}gtk-*/WebKit{Web,Network}Process rix,

  /usr/share/enchant*/{,**} r,

  owner /bindfile@{rand6} rw,
  owner @{att}/.flatpak-info r,

  owner @{user_config_dirs}/glib-2.0/ w,
  owner @{user_config_dirs}/glib-2.0/settings/ w,

  owner @{tmp}/ContentRuleList@{rand6} rw,
  owner @{tmp}/epiphany-*-@{rand6}/{,**} rw,
  owner @{tmp}/Serialized@{rand9} rw,
  owner @{tmp}/WebKit-Media-@{rand6} rw,

  owner @{run}/user/@{uid}/.dbus-proxy/{system,session,a11y}-bus-proxy-@{rand6} rw,
  owner @{run}/user/@{uid}/.flatpak/ w,
  owner @{run}/user/@{uid}/.flatpak/webkit-*/{,bwrapinfo.json} rw,
  owner @{run}/user/@{uid}/webkitgtk/ w,
  owner @{run}/user/@{uid}/webkitgtk/a11y-proxy-@{rand6} rw,
  owner @{run}/user/@{uid}/webkitgtk/bus-proxy-@{rand6} rw,
  owner @{run}/user/@{uid}/webkitgtk/dbus-proxy-@{rand6} rw,

  @{sys}/devices/virtual/dmi/id/chassis_type r,
  @{sys}/firmware/acpi/pm_profile r,
  @{sys}/fs/cgroup/user.slice/user-@{uid}.slice/user@@{uid}.service/app.slice/app-gnome-org.gnome.Epiphany-@{int}.scope/memory.* r,

        @{PROC}/@{pid}/cgroup r,
        @{PROC}/sys/net/ipv6/conf/all/disable_ipv6 r,
        @{PROC}/zoneinfo r,
  owner @{PROC}/@{pid}/smaps r,
  owner @{PROC}/@{pid}/statm r,

  deny @{user_share_dirs}/gvfs-metadata/* r,

  /dev/video@{int} rw,

  include if exists <local/epiphany>
}

# vim:syntax=apparmor
